package org.jeecg.modules.api.okki.site.controller;

import java.security.Key;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.codec.binary.Base64;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.api.okki.site.dto.CreateSiteDto;
import org.jeecg.modules.api.okki.site.entity.OkkiSite;
import org.jeecg.modules.api.okki.site.service.IOkkiSiteService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import sun.plugin.com.Utils;

import static org.jeecg.modules.api.okki.utils.AESUtils.*;

/**
 * @Description: 站点
 * @Author: jeecg-boot
 * @Date:   2024-04-29
 * @Version: V1.0
 */
@Api(tags="站点")
@RestController
@RequestMapping("/site/okkiSite")
@Slf4j
public class OkkiSiteController extends JeecgController<OkkiSite, IOkkiSiteService> {
	@Autowired
	private IOkkiSiteService okkiSiteService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiSite
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "站点-分页列表查询")
	@ApiOperation(value="站点-分页列表查询", notes="站点-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiSite>> queryPageList(OkkiSite okkiSite,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiSite> queryWrapper = QueryGenerator.initQueryWrapper(okkiSite, req.getParameterMap());
		Page<OkkiSite> page = new Page<OkkiSite>(pageNo, pageSize);
		IPage<OkkiSite> pageList = okkiSiteService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiSite
	 * @return
	 */
	@AutoLog(value = "站点-添加")
	@ApiOperation(value="站点-添加", notes="站点-添加")
	@RequiresPermissions("site:okki_site:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiSite okkiSite) {
		okkiSiteService.save(okkiSite);
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param okkiSite
	 * @return
	 */
	@AutoLog(value = "站点-编辑")
	@ApiOperation(value="站点-编辑", notes="站点-编辑")
	@RequiresPermissions("site:okki_site:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiSite okkiSite) {
		okkiSiteService.updateById(okkiSite);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "站点-通过id删除")
	@ApiOperation(value="站点-通过id删除", notes="站点-通过id删除")
	@RequiresPermissions("site:okki_site:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiSiteService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "站点-批量删除")
	@ApiOperation(value="站点-批量删除", notes="站点-批量删除")
	@RequiresPermissions("site:okki_site:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiSiteService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "站点-通过id查询")
	@ApiOperation(value="站点-通过id查询", notes="站点-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiSite> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiSite okkiSite = okkiSiteService.getById(id);
		if(okkiSite==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiSite);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiSite
    */
    @RequiresPermissions("site:okki_site:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiSite okkiSite) {
        return super.exportXls(request, okkiSite, OkkiSite.class, "站点");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("site:okki_site:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiSite.class);
    }

}
